==> v0.13.11.tar.gz: git-next/crates/cli/src/repo/tests/handlers/load_config_from_repo.rs <==
//
use super::*;

#[actix::test]
async fn when_read_file_ok_should_send_config_loaded() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    let mut load_config_open_repo = MockOpenRepositoryLike::new();
    let branches = given::repo_branches();
    let remote_branches = vec![branches.main(), branches.next(), branches.dev()];
    load_config_open_repo
        .expect_read_file()
        .return_once(move |_, _| {
            Ok(format!(
                r#"
        [branches]
        main = "{}"
        next = "{}"
        dev = "{}"
        "#,
                branches.main(),
                branches.next(),
                branches.dev()
            ))
        });

    load_config_open_repo
        .expect_remote_branches()
        .return_once(|| Ok(remote_branches));

    open_repository
        .expect_duplicate()
        .return_once(|| Box::new(load_config_open_repo));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    addr.send(crate::repo::messages::LoadConfigFromRepo::new())
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: ReceiveRepoConfig")?;
    log.no_message_contains("send: NotifyUsers")?;
    Ok(())
}

#[actix::test]
async fn when_read_file_err_should_notify_user() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    let mut load_config_open_repo = MockOpenRepositoryLike::new();
    load_config_open_repo
        .expect_read_file()
        .return_once(move |_, _| Err(git::file::Error::FileNotFound));

    open_repository
        .expect_duplicate()
        .return_once(|| Box::new(load_config_open_repo));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    addr.send(crate::repo::messages::LoadConfigFromRepo::new())
        .await?;
    System::current().stop();

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: NotifyUser")?;
    log.no_message_contains("send: ReceiveRepoConfig")?;
    Ok(())
}

==> v0.14.1.tar.gz: git-next/crates/cli/src/repo/tests/handlers/load_config_from_repo.rs <==
use crate::{repo::messages::LoadConfigFromRepo, tell};

//
use super::*;

#[tokio::test]
async fn when_read_file_ok_should_send_config_loaded() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    // let mut load_config_open_repo = MockOpenRepositoryLike::new();
    let branches = given::repo_branches();
    let remote_branches = vec![branches.main(), branches.next(), branches.dev()];
    open_repository.expect_read_file().return_once(move |_, _| {
        Ok(format!(
            r#"
        [branches]
        main = "{}"
        next = "{}"
        dev = "{}"
        "#,
            branches.main(),
            branches.next(),
            branches.dev()
        ))
    });

    open_repository
        .expect_remote_branches()
        .return_once(|| Ok(remote_branches));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    tell!(addr, LoadConfigFromRepo::new())?;

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: ReceiveRepoConfig")
        .await?;
    log.no_message_contains("send: NotifyUsers").await?;
    Ok(())
}

#[tokio::test]
async fn when_read_file_err_should_notify_user() -> TestResult {
    //given
    let fs = given::a_filesystem();
    let (mut open_repository, repo_details) = given::an_open_repository(&fs);
    open_repository
        .expect_read_file()
        .return_once(move |_, _| Err(git::file::Error::FileNotFound));

    //when
    let (addr, log) = when::start_actor_with_open_repository(
        Box::new(open_repository),
        repo_details,
        given::a_forge(),
    );
    tell!(addr, LoadConfigFromRepo::new())?;

    //then
    tracing::debug!(?log, "");
    log.require_message_containing("send: NotifyUser").await?;
    log.no_message_contains("send: ReceiveRepoConfig").await?;
    Ok(())
}
